Cell class

Constructors

Cell(String content, {int columnSpan = 1, int rowSpan = 1, CellStyle? style})
const

Properties

columnSpan → int
final
content → String
final
hashCode → int
The hash code for this object.
no setteroverride
rowSpan → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → CellStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override