Table class

Available extensions

Constructors

Table({TableSection? header, required TableSection body, TableSection? footer, CellStyle cellStyle = const CellStyle(), TableStyle? tableStyle})

Properties

body → TableSection
final
cellStyle → CellStyle
final
columnCount ↔ int?
getter/setter pair
final
hashCode → int
The hash code for this object.
no setteroverride
final
positionedCells ↔ List<PositionedCell>
getter/setter pair
rowCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableStyle → TableStyle?
final

Methods

getOrNull(int row, int column) → PositionedCell?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({TextLayout layoutFactory(PositionedCell) = _simpleLayoutFactory, TextBorder? border}) → String

Available on Table, provided by the Render extension

toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override